# Wyrdle
![Funny badge](https://forthebadge.com/images/badges/60-percent-of-the-time-works-every-time.svg)

This is a Python implementation of the viral word game, [Wordle](https://www.powerlanguage.co.uk/wordle/), by [Josh Wardle](https://www.powerlanguage.co.uk/) (ohh, so that's where the name is from).

Additionally, a bot is included that tries to win the game with its own strategy!

## Installation
Install from PyPI using
```sh
pip install wyrdle
```

## Usage
You can play today's Wordle right from your terminal! Simply run
```sh
wordle
```

Feeling lazy? Feeling competitive? (We're going full Google search button here.)  
Then let the bot play:
```sh
wordle -b
```

### Example
Here is the bot's run against `smile`:
> Wordle 666 2/6  
>   
> 🟩🟨⬛⬛🟩  
> 🟩🟩🟩🟩🟩  

Impressive!
